"""
функция дискретного преобразования Фурье с плавающим окном на частоте 50 Гц
принимает на вход:
Xmag - массив для амплитуд, размер Nx3
Xphase - массив для фаз, размер Nx3
sim_time - массив времени моделирования, размер Nx1
signal - массив исходных сигналов во временной области, размер Nx3

функция возвращает изменённые массивы Xmag и Xphase
"""

function moving_fourie(Xmag, Xphase, sim_time, signal)
    Xw = complex(zeros(Int(0.02/sim_time[2]),3));
    Xcomp = zeros(3);
    j = 1;
    for i = 1:length(sim_time)
        Xw[j,:] = signal[i,1:3] .* exp(-1im*2*pi*50*sim_time[i]);
        Xcomp = sum(Xw,dims=1) .* (2*1im/(0.02/sim_time[2]));
        Xmag[i,:] = abs.(Xcomp);
        Xphase[i,:] = angle.(Xcomp) .* (180/pi);
        j = j + 1;
        if j > 0.02/sim_time[2] # число точек на период 50 Гц
            j = 1;
        end
    end
    return (Xmag, Xphase)
end